
Rattail
=======

Rattail is a retail software framework, released under the GNU General Public
License.

This is the core ``rattail`` package.

Please see Rattail's `home page`_ for more information.

.. _home page: https://rattailproject.org/
